Jep 3.1 Release Notes
*********************
This release emphasized JDBC support and bug fixes. It is compatible with
Python 2.6 and 2.7.


Lazy loading of standard JDK packages
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Jep now lazily loads classes with a package name starting with java.*.


JDBC support
~~~~~~~~~~~~
Jep now includes a jdbc module for JDBC interactions.

http://www.oracle.com/technetwork/java/javase/jdbc/index.html

